@@ -45,12 +45,12 @@ def main():
             produto_bling = bling_controller.get_produto(str(row[0]))
 
             if produto_skyhub:
-                print(produto_skyhub)
+                print(index, produto_skyhub)
                 if produto_skyhub.price != row[1] or produto_skyhub.qty != row[2]:
                     skyhub_controller.atualiza_produto(produto_estoque)
 
             if produto_bling:
-                print(produto_bling)
+                print(index, produto_bling)
                 if produto_bling.price != row[1] or produto_bling.qty != row[2]:
                     bling_controller.atualiza_produto(produto_estoque)
 
@@ -62,5 +62,5 @@ if __name__ == "__main__":
     except KeyboardInterrupt:
         sys.exit()
 
-    except Exception as e:
-        send_message(e)
+    # except Exception as e:
+    #     send_message(e)
